@@ -24,7 +24,7 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     required_field = "webhook"
     author = "Mo"
     author_url = "https://github.com/M-Davinci/dt_notify_to_people"
-    version = "1.8.7"
+    version = "1.8.8"
     resource_links = [
         ("Report Issue", "https://github.com/M-Davinci/dt_notify_to_people/issues"),
         ("View Source", "https://github.com/M-Davinci/dt_notify_to_people"),
@@ -112,10 +112,10 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
     def notify_about_activity(self, activity):
         project = activity.project
         group = activity.group
-
         self._post(group, project, activity)
 
     def _post(self, group, project, event=''):
+
         custom_keyword = self.get_option("custom_keyword", project)
         # 告警次数阀值
         number_alarm = self.get_option("number_alarm", project) if self.get_option("number_alarm", project) else 1
@@ -124,23 +124,13 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         issue_link = group.get_absolute_url(params={"referrer": "dingtalknotify"})
         issue_link = issue_link.replace('https', 'http')
 
-
         payload = f"## {custom_keyword}\n\n" if custom_keyword else ""
         payload = f"{payload} > 项目名称: {project.name} \n\n"
         payload = f"{payload} > 出现次数: {group.times_seen} \n\n"
-        payload = f"{payload} > 查看详情: <font color=blue>[{group.title if 'unknown' not in group.title else 'unknown'}]({issue_link})</font> \n\n"
+        payload = f"{payload} > 查看详情: <font color=blue>[{group.message[0:30]}]({issue_link})</font> \n\n"
         payload = f"{payload} > 具体报错: {group.message} \n\n"
-        # payload = f"{payload} > 全部报错: {group.__dict__} \n\n"
-        payload = f"{payload} > Hi: {event.__dict__} \n\n"
-        payload = f"{payload} > Hi: {event.data} \n\n"
-        # payload = f"{payload} > Group: {group.__dict__} \n\n"
-        # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__} \n\n"
-        # payload = f"{payload} > 全部报错: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__} \n\n"
-        # payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__} \n\n"
-        # payload = f"{payload} > _state: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['_state'].__dict__['fields_cache']['organization'].__dict__} \n\n"
-        # payload = f"{payload} > flags: {group.__dict__['_state'].__dict__['fields_cache']['project'].__dict__['flags'].__dict__} \n\n"
-
-        # payload = f"{payload} > _state: {project.__dict__} \n\n"
+        # payload = f"{payload} > Hi: {event.__dict__} \n\n"
+        # payload = f"{payload} > Hi: {event.data} \n\n"
 
         headers = {
             "Content-type": "application/json",
@@ -148,7 +138,6 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
             "charset": "utf8"
         }
 
-
         # 一次通知多人，传递过来的电话号码为字符串拼接，形如：'187888823,1234866899'
         notify_user = []
         phone = ''
@@ -176,4 +165,3 @@ class DingTalkNotifyPlugin(CorePluginMixin, notify.NotificationPlugin):
         if group.status == 0 and group.times_seen > number_alarm and not bool(event.data):
             for webhook_url in self.get_webhook_urls(group.project):
                 requests.post(webhook_url, data=json.dumps(data_1), headers=headers)
-
